@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: analysis.c,v 1.246 2017/10/11 21:54:50 plm Exp $
+ * $Id: analysis.c,v 1.248 2018/04/21 20:12:08 plm Exp $
  */
 
 #include "config.h"
@@ -105,8 +105,10 @@ LuckFirst(const TanBoard anBoard, const int n0, const int n1, cubeinfo * pci, co
 
             /* Find the best move for each roll at ply 0 only. */
             if (FindnSaveBestMoves(&ml, i + 1, j + 1, (ConstTanBoard) anBoardTemp, NULL, 0.0f,
-                                   pci, pec, defaultFilters) < 0)
+                                   pci, pec, defaultFilters) < 0) {
+                free(ml.amMoves);
                 return ERR_VAL;
+            }
 
             if (!ml.cMoves) {
 
@@ -141,8 +143,10 @@ LuckFirst(const TanBoard anBoard, const int n0, const int n1, cubeinfo * pci, co
 
             /* Find the best move for each roll at ply 0 only. */
             if (FindnSaveBestMoves(&ml, i + 1, j + 1, (ConstTanBoard) anBoardTemp, NULL, 0.0f,
-                                   &ciOpp, pec, defaultFilters) < 0)
+                                   &ciOpp, pec, defaultFilters) < 0) {
+                free(ml.amMoves);
                 return ERR_VAL;
+            }
 
             if (!ml.cMoves) {
 
@@ -194,8 +198,10 @@ LuckNormal(const TanBoard anBoard, const int n0, const int n1, const cubeinfo *
 
             /* Find the best move for each roll at ply 0 only. */
             if (FindnSaveBestMoves(&ml, i + 1, j + 1, (ConstTanBoard) anBoardTemp, NULL, 0.0f,
-                                   pci, pec, defaultFilters) < 0)
+                                   pci, pec, defaultFilters) < 0) {
+                free(ml.amMoves);
                 return ERR_VAL;
+            }
 
             if (!ml.cMoves) {
 
@@ -683,8 +689,10 @@ AnalyzeMove(moverecord * pmr, matchstate * pms, const listOLD * plParentGame,
                     if (FindnSaveBestMoves(&ml, pmr->anDice[0],
                                            pmr->anDice[1],
                                            (ConstTanBoard) pms->anBoard, &key,
-                                           arSkillLevel[SKILL_DOUBTFUL], &ci, &pesChequer->ec, aamf) < 0)
+                                           arSkillLevel[SKILL_DOUBTFUL], &ci, &pesChequer->ec, aamf) < 0) {
+                        free(ml.amMoves);
                         return -1;
+                    }
                     MT_Exclusive();
                     CopyMoveList(&pmr->ml, &ml);
                     if (ml.cMoves)
@@ -716,7 +724,7 @@ AnalyzeMove(moverecord * pmr, matchstate * pms, const listOLD * plParentGame,
 
         dt = DoubleType(pms->fDoubled, pms->fMove, pms->fTurn);
 
-        if (dt != DT_NORMAL)
+        if (dt > DT_NORMAL)	/* TODO: analyse beavers */
             break;
 
         /* cube action */
@@ -767,7 +775,7 @@ AnalyzeMove(moverecord * pmr, matchstate * pms, const listOLD * plParentGame,
             break;
 
         tt = (taketype) DoubleType(pms->fDoubled, pms->fMove, pms->fTurn);
-        if (tt > TT_NORMAL)
+        if (tt > TT_NORMAL)	/* TODO: analyse beavers */
             break;
 
         if (fAnalyseCube && pmgi->fCubeUse && doubleError && (*doubleError != ERR_VAL)) {
@@ -787,7 +795,7 @@ AnalyzeMove(moverecord * pmr, matchstate * pms, const listOLD * plParentGame,
             break;
 
         tt = (taketype) DoubleType(pms->fDoubled, pms->fMove, pms->fTurn);
-        if (tt > TT_NORMAL)
+        if (tt > TT_NORMAL)	/* TODO: analyse beavers */
             break;
 
         if (fAnalyseCube && pmgi->fCubeUse && doubleError && (*doubleError != ERR_VAL)) {
@@ -1044,6 +1052,8 @@ AddStatcontext(const statcontext * pscA, statcontext * pscB)
 
     int i, j;
 
+    MT_Exclusive();
+
     pscB->nGames++;
 
     pscB->fMoves |= pscA->fMoves;
@@ -1104,7 +1114,7 @@ AddStatcontext(const statcontext * pscA, statcontext * pscB)
         }
 
     }
-
+    MT_Release();
 }
 
 static int
