@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: font3d.c,v 1.32 2015/02/01 20:10:43 plm Exp $
+ * $Id: font3d.c,v 1.33 2016/11/23 07:48:33 plm Exp $
  */
 
 #include "config.h"
@@ -95,7 +95,6 @@ int
 CreateFontText(OGLFont ** ppFont, const char *text, const char *fontFile, int pitch, float size, float heightRatio)
 {
     char *filename;
-
     FT_Library ftLib;
     if (FT_Init_FreeType(&ftLib))
         return 0;
@@ -116,15 +115,19 @@ CreateFontText(OGLFont ** ppFont, const char *text, const char *fontFile, int pi
 void
 FreeNumberFont(OGLFont * ppFont)
 {
-    glDeleteLists(ppFont->glyphs, 10);
-    ppFont->glyphs = 0;
+    if (ppFont) {
+        glDeleteLists(ppFont->glyphs, 10);
+        ppFont->glyphs = 0;
+    }
 }
 
 void
 FreeFontText(OGLFont * ppFont)
 {
-    glDeleteLists(ppFont->glyphs, 1);
-    ppFont->glyphs = 0;
+    if (ppFont) {
+        glDeleteLists(ppFont->glyphs, 1);
+        ppFont->glyphs = 0;
+    }
 }
 
 static int
@@ -467,7 +470,7 @@ PopulateContour(GArray * contour, const FT_Vector * points, const char *pointTag
 
 /* Unfortunately the glu library doesn't define this callback type precisely
  * so it may well cause problems on different platforms / opengl implementations */
-#ifdef WIN32
+#if defined(WIN32)
 /* Need to set the callback calling convention for windows */
 #define TESS_CALLBACK APIENTRY
 #else
@@ -477,7 +480,7 @@ PopulateContour(GArray * contour, const FT_Vector * points, const char *pointTag
 #if defined(USE_APPLE_OPENGL)
 #define GLUFUN(X) X
 #elif defined(__GNUC__)
-#if WIN32
+#if defined(WIN32)
 typedef APIENTRY GLvoid (*_GLUfuncptr)();
 #endif
 #define GLUFUN(X) (_GLUfuncptr)X
