@@ -18,13 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: model.c,v 1.19 2013/06/16 02:16:23 mdpetch Exp $
+ * $Id: model.c,v 1.22 2018/04/28 21:44:35 plm Exp $
  */
 
 #include "config.h"
 #include "inc3d.h"
 
-#define TOP_EDGE -2
+#define TOP_EDGE (-2)
 
 typedef struct _position {
     float x, y, z;
@@ -60,7 +60,7 @@ freeOccluder(Occluder * pOcc)
         g_array_free(pOcc->handle->edges, TRUE);
         g_array_free(pOcc->handle->points, TRUE);
         free(pOcc->handle);
-        pOcc->handle = 0;
+        pOcc->handle = NULL;
         glDeleteLists(pOcc->shadow_list, 1);
     }
 }
@@ -489,14 +489,23 @@ addCylinder(Occluder * pOcc, float x, float y, float z, float r, float d, unsign
 void
 addHalfTube(Occluder * pOcc, float r, float h, unsigned int numSteps)
 {
-    float step = ((2 * (float) G_PI) / numSteps) / 2.0f;
-    float *xPts = (float *) malloc(sizeof(float) * (numSteps + 1));
-    float *yPts = (float *) malloc(sizeof(float) * (numSteps + 1));
+    float *xPts, *yPts;
+    float step;
     unsigned int i;
+  
+    if (numSteps == 0) {
+        g_assert_not_reached();
+        return;
+    }
+
+    step = ((2 * (float) G_PI) / numSteps) / 2.0f;
+
+    xPts = (float *) malloc(sizeof(float) * (numSteps + 1));
+    yPts = (float *) malloc(sizeof(float) * (numSteps + 1));
     g_assert(xPts && yPts);
 
     for (i = 0; i <= numSteps; i++) {
-        float ang = step * i - ((float) G_PI / 2.0f);
+        float ang = step * i - (float) G_PI_2;
         xPts[i] = sinf(ang) * r;
         yPts[i] = cosf(ang) * r;
     }
