@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: widget3d.c,v 1.54 2016/05/14 22:28:32 plm Exp $
+ * $Id: widget3d.c,v 1.56 2018/03/04 14:56:06 plm Exp $
  */
 
 #include "config.h"
@@ -176,16 +176,17 @@ CreateGLWidget(BoardData * bd)
     /* Drawing area for OpenGL */
     p3dWidget = bd->bd3d->drawing_area3d = gtk_drawing_area_new();
 
+    if (p3dWidget == NULL) {
+        g_print("Can't create opengl drawing widget\n");
+        return FALSE;
+    }
+
     /* Set OpenGL-capability to the widget - no list sharing */
     if (!gtk_widget_set_gl_capability(p3dWidget, getGlConfig(), NULL, TRUE, GDK_GL_RGBA_TYPE)) {
         g_print("Can't create opengl capable widget\n");
         return FALSE;
     }
 
-    if (p3dWidget == NULL) {
-        g_print("Can't create opengl drawing widget\n");
-        return FALSE;
-    }
     /* set up events and signals for OpenGL widget */
     gtk_widget_set_events(p3dWidget, GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK |
                           GDK_BUTTON_RELEASE_MASK | GDK_BUTTON_MOTION_MASK);
@@ -208,115 +209,6 @@ InitGTK3d(int *argc, char ***argv)
     SetupFlag();
 }
 
-/* This doesn't seem to work even on windows anymore... */
-#ifdef TEMP_REMOVE
-
-#ifndef PFD_GENERIC_ACCELERATED
-#define PFD_GENERIC_ACCELERATED     0x00001000
-#endif
-
-void
-getFormatDetails(HDC hdc, int *accl, int *dbl, int *col, int *depth, int *stencil, int *accum)
-{
-    PIXELFORMATDESCRIPTOR pfd;
-
-    /* Use current format */
-    int format = GetPixelFormat(hdc);
-    if (format == 0) {
-        g_print("Unable to find pixel format.\n");
-        return;
-    }
-    ZeroMemory(&pfd, sizeof(pfd));
-    pfd.nSize = sizeof(pfd);
-    pfd.nVersion = 1;
-
-    if (!DescribePixelFormat(hdc, format, sizeof(PIXELFORMATDESCRIPTOR), &pfd)) {
-        g_print("Unable to describe pixel format.\n");
-        return;
-    }
-
-    *accl = !((pfd.dwFlags & PFD_GENERIC_FORMAT) && !(pfd.dwFlags & PFD_GENERIC_ACCELERATED));
-    *dbl = pfd.dwFlags & PFD_DOUBLEBUFFER;
-    *col = pfd.cColorBits;
-    *depth = pfd.cDepthBits;
-    *stencil = pfd.cStencilBits;
-    *accum = pfd.cAccumBits;
-}
-
-static int
-CheckAccelerated(GtkWidget * board)
-{
-    GdkGLDrawable *gldrawable = gtk_widget_get_gl_drawable(board);
-
-    if (!gdk_gl_drawable_gl_begin(gldrawable, gtk_widget_get_gl_context(board)))
-        return 1;
-    {
-        int accl = 0, dbl, col, depth, stencil, accum;
-        HDC dc = wglGetCurrentDC();
-
-        /* Display graphics card details
-         * HGLRC hglrc = wglGetCurrentContext();
-         * g_print("(hglrc:%p, dc:%p).\n", hglrc, dc);
-         * 
-         * const char* vendor = glGetString(GL_VENDOR);
-         * const char* renderer = glGetString(GL_RENDERER);
-         * const char* version = glGetString(GL_VERSION);
-         * 
-         * g_print("\n3d graphics card details\n\n");
-         * g_print("Vendor: %s\n", vendor);
-         * g_print("Renderer: %s\n", renderer);
-         * g_print("Version: %s\n", version);
-         */
-
-        if (!dc)
-            g_print("No DC found.\n");
-        else {
-            getFormatDetails(dc, &accl, &dbl, &col, &depth, &stencil, &accum);
-            /*
-             * g_print("%sAccelerated\n(%s, %d bit col, %d bit depth, %d bit stencil, %d bit accum)\n",
-             * accl ? "" : "NOT ", dbl?"Double buffered":"Single buffered", col, depth, stencil, accum);
-             */
-        }
-        gdk_gl_drawable_gl_end(gldrawable);
-
-        return accl;
-    }
-}
-
-/* Unsupported (linux) version */
-
-static int
-CheckAccelerated(GtkWidget * notused)
-{
-    /* Commented out check for non-windows systems,
-     * as doesn't work very well... */
-    return TRUE;
-    /*
-     * Display* display = glXGetCurrentDisplay();
-     * GLXContext context = glXGetCurrentContext();
-     * if (!display || !context)
-     * {
-     * g_print("Unable to get current display information.\n");
-     * return 1;
-     * }
-     * return glXIsDirect(display, context);
-     */
-}
-
-#endif
-
-int
-DoAcceleratedCheck(const BoardData3d * UNUSED(bd3d), GtkWidget * UNUSED(pwParent))
-{                               /* Currently not supported (code out of date/unwritten) */
-#ifdef TEMP_REMOVE
-    if (!CheckAccelerated(bd3d->drawing_area3d)) {      /* Display warning message as performance may be bad */
-        GTKShowWarning(WARN_UNACCELERATED, pwParent);
-        return 0;
-    } else
-#endif
-        return 1;
-}
-
 void
 RenderToBuffer3d(const BoardData * bd, BoardData3d * bd3d, unsigned int width, unsigned int height, unsigned char *buf)
 {
