@@ -1,7 +1,7 @@
 /*
  * export.h
  *
- * by Jrn Thyssen  <jthyssen@dk.ibm.com>, 2002.
+ * by Joern Thyssen  <jthyssen@dk.ibm.com>, 2002.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 3 or later of the GNU General Public License as
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: export.h,v 1.38 2013/06/16 02:16:11 mdpetch Exp $
+ * $Id: export.h,v 1.40 2018/06/05 19:24:05 plm Exp $
  */
 
 #include "render.h"
@@ -26,9 +26,9 @@
 #ifndef EXPORT_H
 #define EXPORT_H
 
-#define EXPORT_CUBE_ACTUAL   7
-#define EXPORT_CUBE_MISSED   8
-#define EXPORT_CUBE_CLOSE    9
+#define EXPORT_CUBE_ACTUAL   4
+#define EXPORT_CUBE_MISSED   5
+#define EXPORT_CUBE_CLOSE    6
 
 
 typedef enum _htmlexporttype {
@@ -67,13 +67,13 @@ typedef struct _exportsetup {
     unsigned int nMoves;        /* show at most nMoves */
     int fMovesDetailProb;       /* show detailed probabilities */
     int afMovesParameters[2];   /* detailed parameters */
-    int afMovesDisplay[7];      /* display moves */
+    int afMovesDisplay[4];      /* display moves */
 
     /* cube */
 
     int fCubeDetailProb;        /* show detailed probabilities */
     int afCubeParameters[2];    /* detailed parameters */
-    int afCubeDisplay[10];      /* display moves */
+    int afCubeDisplay[7];       /* display cube actions */
 
     /* FIXME: add format specific options */
 
@@ -96,7 +96,7 @@ extern char *filename_from_iGame(const char *szBase, const int iGame);
 extern int WritePNG(const char *sz, unsigned char *puch,
                     unsigned int nStride, unsigned int nSizeX, unsigned int nSizeY);
 
-#if USE_BOARD3D
+#if defined(USE_BOARD3D)
 void GenerateImage3d(const char *szName, unsigned int nSize, unsigned int nSizeX, unsigned int nSizeY);
 #endif
 
