@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.5.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,49 +26,57 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+#ifndef YY_YY_EXTERNAL_Y_H_INCLUDED
+# define YY_YY_EXTERNAL_Y_H_INCLUDED
+/* Debug traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+#if YYDEBUG
+extern int yydebug;
+#endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     EOL = 258,
-     EXIT = 259,
-     DISABLED = 260,
-     INTERFACEVERSION = 261,
-     DEBUG = 262,
-     SET = 263,
-     NEW = 264,
-     OLD = 265,
-     OUTPUT = 266,
-     E_INTERFACE = 267,
-     HELP = 268,
-     PROMPT = 269,
-     E_STRING = 270,
-     E_CHARACTER = 271,
-     E_INTEGER = 272,
-     E_FLOAT = 273,
-     E_BOOLEAN = 274,
-     FIBSBOARD = 275,
-     FIBSBOARDEND = 276,
-     EVALUATION = 277,
-     CRAWFORDRULE = 278,
-     JACOBYRULE = 279,
-     RESIGNATION = 280,
-     BEAVERS = 281,
-     CUBE = 282,
-     CUBEFUL = 283,
-     CUBELESS = 284,
-     DETERMINISTIC = 285,
-     NOISE = 286,
-     PLIES = 287,
-     PRUNE = 288
-   };
+  enum yytokentype
+  {
+    EOL = 258,
+    EXIT = 259,
+    DISABLED = 260,
+    INTERFACEVERSION = 261,
+    DEBUG = 262,
+    SET = 263,
+    NEW = 264,
+    OLD = 265,
+    OUTPUT = 266,
+    E_INTERFACE = 267,
+    HELP = 268,
+    PROMPT = 269,
+    E_STRING = 270,
+    E_CHARACTER = 271,
+    E_INTEGER = 272,
+    E_FLOAT = 273,
+    E_BOOLEAN = 274,
+    FIBSBOARD = 275,
+    FIBSBOARDEND = 276,
+    EVALUATION = 277,
+    CRAWFORDRULE = 278,
+    JACOBYRULE = 279,
+    RESIGNATION = 280,
+    BEAVERS = 281,
+    CUBE = 282,
+    CUBEFUL = 283,
+    CUBELESS = 284,
+    DETERMINISTIC = 285,
+    NOISE = 286,
+    PLIES = 287,
+    PRUNE = 288
+  };
 #endif
 /* Tokens.  */
 #define EOL 258
@@ -103,15 +111,12 @@
 #define PLIES 287
 #define PRUNE 288
 
-
-
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
-{
 
-/* Line 2068 of yacc.c  */
-#line 116 "external_y.y"
+union YYSTYPE
+{
+#line 116 "external_y.y" /* yacc.c:1909  */
 
     gboolean bool;
     gchar character;
@@ -122,16 +127,16 @@ typedef union YYSTYPE
     GList *list;
     commandinfo *cmd;
 
+#line 131 "external_y.h" /* yacc.c:1909  */
+};
 
-
-/* Line 2068 of yacc.c  */
-#line 129 "external_y.h"
-} YYSTYPE;
+typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
 
 
+int yyparse (scancontext *scanner);
 
+#endif /* !YY_YY_EXTERNAL_Y_H_INCLUDED  */
