@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkboard.h,v 1.106 2016/08/19 22:57:24 plm Exp $
+ * $Id: gtkboard.h,v 1.107 2018/05/05 20:52:19 plm Exp $
  */
 
 #ifndef GTKBOARD_H
@@ -95,7 +95,7 @@ struct _BoardData {
     gint points[28];            /* 0 and 25 are the bars */
     gint turn;                  /* -1 is X, 1 is O, 0 if game over */
     unsigned int diceRoll[2];   /* 0, 0 if not rolled */
-    gint cube;
+    guint cube;
     gint can_double, opponent_can_double;       /* allowed to double */
     gint doubled;               /* -1 if X is doubling, 1 if O is doubling */
     gint colour;                /* -1 for player X, 1 for player O */
