@@ -16,16 +16,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkcube.h,v 1.4 2007/07/02 12:43:39 ace Exp $
+ * $Id: gtkcube.h,v 1.11 2013/06/16 02:16:14 mdpetch Exp $
  */
 
-#ifndef _GTKCUBE_H_
-#define _GTKCUBE_H_
+#ifndef GTKCUBE_H
+#define GTKCUBE_H
 
-extern GtkWidget *
-CreateCubeAnalysis ( float aarOutput[ 2 ][ NUM_ROLLOUT_OUTPUTS ],
-                     float aarStdDev[ 2 ][ NUM_ROLLOUT_OUTPUTS ],
-                     evalsetup *pes,
-                     const movetype mt );
+extern GtkWidget *CreateCubeAnalysis(moverecord * pmr, const matchstate * pms, int did_double, int did_take, int hist);
 
 #endif
