@@ -19,7 +19,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkfile.c,v 1.67 2014/07/20 21:10:26 plm Exp $
+ * $Id: gtkfile.c,v 1.72 2017/09/25 19:05:52 plm Exp $
  */
 
 #include "config.h"
@@ -37,6 +37,7 @@
 
 #include "gtkfile.h"
 #include "gtkgame.h"
+#include "gtktoolbar.h"
 #include "gtkwindows.h"
 #include "file.h"
 #include "util.h"
@@ -88,7 +89,7 @@ GnuBGFileDialog(const gchar * prompt, const gchar * folder, const gchar * name,
     if ((pc = strrchr(programdir, G_DIR_SEPARATOR)) != NULL) {
         *pc = '\0';
 
-        tmp = g_build_filename(programdir, "GamesGrid", "SaveGame", NULL);
+        tmp = g_build_filename(programdir, "GridGammon", "SaveGame", NULL);
         gtk_file_chooser_add_shortcut_folder(GTK_FILE_CHOOSER(fc), tmp, NULL);
         g_free(tmp);
 
@@ -164,11 +165,11 @@ SaveCommon(guint f, gchar * prompt)
     GtkWidget *hbox;
     guint i, j, type;
     SaveOptions so;
-    static guint last_export_type = 0;
+    static ExportType last_export_type = EXPORT_SGF;
     static guint last_export_mgp = 0;
     static gchar *last_save_folder = NULL;
     static gchar *last_export_folder = NULL;
-    gchar *fn = GetFilename(TRUE, (f == 1) ? 0 : last_export_type);
+    gchar *fn = GetFilename(TRUE, (f == 1) ? EXPORT_SGF : last_export_type);
     gchar *folder = NULL;
     const gchar *mgp_text[3] = { "match", "game", "position" };
 
@@ -199,7 +200,11 @@ SaveCommon(guint f, gchar * prompt)
     so.upext = gtk_check_button_new_with_label(_("Update extension"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(so.upext), TRUE);
 
+#if GTK_CHECK_VERSION(3,0,0)
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 10);
+#else
     hbox = gtk_hbox_new(FALSE, 10);
+#endif
     gtk_box_pack_start(GTK_BOX(hbox), so.mgp, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(hbox), so.description, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(hbox), so.upext, TRUE, TRUE, 0);
@@ -222,7 +227,7 @@ SaveCommon(guint f, gchar * prompt)
                 cmd = g_strdup_printf("save %s \"%s\"", et, fn);
             else
                 cmd = g_strdup_printf("export %s %s \"%s\"", et, export_format[type].clname, fn);
-            last_export_type = type;
+            last_export_type = (ExportType) type;
             last_export_mgp = gtk_combo_box_get_active(GTK_COMBO_BOX(so.mgp));
             g_free(last_export_folder);
             last_export_folder = gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER(so.fc));
@@ -310,7 +315,7 @@ import_types_combo(void)
         gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(type_combo), import_format[i].description);
 
     /* Extra option 'command file' */
-    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(type_combo), _("Gnubg Command file"));
+    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(type_combo), _("GNUbg Command file"));
 
     return type_combo;
 }
@@ -329,10 +334,12 @@ do_import_file(gint import_type, gchar * fn)
     } else {
         cmd = g_strdup_printf("import %s \"%s\"", import_format[import_type].clname, fn);
     }
-    if (cmd)
+    if (cmd) {
+        if (ToolbarIsEditing(NULL))
+            click_edit();
         UserCommand(cmd);
+    }
     g_free(cmd);
-
 }
 
 extern void
@@ -352,13 +359,22 @@ GTKOpen(gpointer UNUSED(p), guint UNUSED(n), GtkWidget * UNUSED(pw))
     type_combo = import_types_combo();
     g_signal_connect(type_combo, "changed", G_CALLBACK(OpenTypeChanged), fc);
 
+#if GTK_CHECK_VERSION(3,0,0)
+    box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+    box2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
     box = gtk_hbox_new(FALSE, 0);
     box2 = gtk_hbox_new(FALSE, 0);
+#endif
     gtk_box_pack_start(GTK_BOX(box), box2, FALSE, FALSE, 0);
     gtk_box_pack_start(GTK_BOX(box2), gtk_label_new(_("Open as:")), FALSE, FALSE, 0);
     gtk_box_pack_start(GTK_BOX(box2), type_combo, FALSE, FALSE, 0);
 
+#if GTK_CHECK_VERSION(3,0,0)
+    box2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
     box2 = gtk_hbox_new(FALSE, 0);
+#endif
     gtk_box_pack_start(GTK_BOX(box), box2, FALSE, FALSE, 10);
     gtk_box_pack_start(GTK_BOX(box2), gtk_label_new(_("Selected file type: ")), FALSE, FALSE, 0);
     selFileType = gtk_label_new("");
@@ -381,8 +397,14 @@ GTKOpen(gpointer UNUSED(p), guint UNUSED(n), GtkWidget * UNUSED(pw))
         } else {
             import_type--;      /* Ignore auto option */
             if (import_type == N_IMPORT_TYPES) {        /* Load command file */
-                CommandLoadCommands(fn);
-                UserCommand("save settings");
+                gchar *cmd = NULL;
+
+                cmd = g_strdup_printf("load commands \"%s\"", fn);
+                if (cmd) {
+                    UserCommand(cmd);
+                    UserCommand("save settings");
+                }
+                g_free(cmd);
             } else {            /* Import as specific type */
                 do_import_file(import_type, fn);
             }
@@ -398,16 +420,18 @@ GTKOpen(gpointer UNUSED(p), guint UNUSED(n), GtkWidget * UNUSED(pw))
 extern void
 GTKCommandsOpen(gpointer UNUSED(p), guint UNUSED(n), GtkWidget * UNUSED(pw))
 {
-    gchar *filename = NULL;
-    gchar *quoted = NULL;
+    gchar *filename = NULL, *cmd = NULL;
     GtkWidget *fc = GnuBGFileDialog(_("Open Commands file"), NULL, NULL, GTK_FILE_CHOOSER_ACTION_OPEN);
 
     if (gtk_dialog_run(GTK_DIALOG(fc)) == GTK_RESPONSE_ACCEPT) {
         filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fc));
-        quoted = g_strdup_printf("'%s'", filename);
-        CommandLoadCommands(quoted);
+        cmd = g_strdup_printf("load commands \"%s\"", filename);
+        if (cmd) {
+            UserCommand(cmd);
+            UserCommand("save settings");
+        }
+        g_free(cmd);
         g_free(filename);
-        g_free(quoted);
     }
     gtk_widget_destroy(fc);
 }
