@@ -16,19 +16,19 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkrelational.h,v 1.10 2008/02/17 12:26:24 c_anthon Exp $
+ * $Id: gtkrelational.h,v 1.12 2013/06/16 02:16:16 mdpetch Exp $
  */
 
 #include "relational.h"
 
 #include <gtk/gtk.h>
 
-#ifndef _GTKRELATIONAL_H_
-#define _GTKRELATIONAL_H_
+#ifndef GTKRELATIONAL_H
+#define GTKRELATIONAL_H
 extern void GtkRelationalAddMatch(gpointer p, guint n, GtkWidget * pw);
 extern void GtkShowRelational(gpointer p, guint n, GtkWidget * pw);
 extern GtkWidget *RelationalOptions(void);
 extern void RelationalOptionsShown(void);
 extern void RelationalSaveOptions(void);
-extern void GtkShowQuery(RowSet* pRow);
+extern void GtkShowQuery(RowSet * pRow);
 #endif
