@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkrolls.c,v 1.42 2017/05/29 15:33:04 plm Exp $
+ * $Id: gtkrolls.c,v 1.44 2018/04/10 22:11:41 plm Exp $
  */
 
 #include "config.h"
@@ -197,7 +197,7 @@ RollsTree(const int n, evalcontext * pec, const matchstate * pms)
     GtkCellRenderer *renderer;
     static const char *aszColumn[] = {
         N_("Roll"),
-        N_("Move"),
+        N_("noun|Move"),
         N_("Equity")
     };
 
@@ -216,7 +216,7 @@ RollsTree(const int n, evalcontext * pec, const matchstate * pms)
         g_object_set(G_OBJECT(renderer), "xalign", 0.0, NULL);
 
         gtk_tree_view_insert_column_with_attributes(GTK_TREE_VIEW(ptv),
-                                                    -1, gettext(aszColumn[i]), renderer, "text", i, NULL);
+                                                    -1, Q_(aszColumn[i]), renderer, "text", i, NULL);
     }
 
     if (fInterrupt) {
