@@ -16,21 +16,18 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtksplash.h,v 1.4 2007/07/02 12:43:39 ace Exp $
+ * $Id: gtksplash.h,v 1.7 2013/06/16 02:16:16 mdpetch Exp $
  */
 
-#ifndef _GTKSPLASH_H_
-#define _GTKSPLASH_H_
+#ifndef GTKSPLASH_H
+#define GTKSPLASH_H
 
-extern GtkWidget *
-CreateSplash ( void );
+extern GtkWidget *CreateSplash(void);
 
 extern void
-DestroySplash ( GtkWidget *pwSplash );
+ DestroySplash(GtkWidget * pwSplash);
 
 extern void
-PushSplash ( GtkWidget *pwSplash, 
-             const gchar *szText0, const gchar *szText1,
-             const unsigned long nMuSec );
+ PushSplash(GtkWidget * pwSplash, const gchar * szText0, const gchar * szText1);
 
-#endif /* _GTKSPLASH_H_ */
+#endif                          /* GTKSPLASH_H */
