@@ -16,13 +16,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtktempmap.h,v 1.6 2013/06/16 02:16:17 mdpetch Exp $
+ * $Id: gtktempmap.h,v 1.7 2015/02/06 23:25:00 plm Exp $
  */
 
 #ifndef GTKTEMPMAP_H
 #define GTKTEMPMAP_H
 
 extern void
- GTKShowTempMap(const matchstate ams[], const int n, const gchar * aszTitle[], const int fInvert);
+ GTKShowTempMap(const matchstate ams[], const int n, gchar * aszTitle[], const int fInvert);
 
 #endif                          /* GTKTEMPMAP_H */
