@@ -15,7 +15,7 @@
  * neuralnet.h
  *
  * by Gary Wong, 1998
- * $Id: neuralnet.h,v 1.33 2016/06/05 19:46:20 plm Exp $
+ * $Id: neuralnet.h,v 1.35 2017/02/18 16:19:44 plm Exp $
  */
 
 #ifndef NEURALNET_H
@@ -54,12 +54,10 @@ typedef struct _NNState {
     float *savedBase;
     float *savedIBase;
 #if !defined(USE_SIMD_INSTRUCTIONS)
-    int cSavedIBase;
+    unsigned int cSavedIBase;
 #endif
 } NNState;
 
-extern int NeuralNetCreate(neuralnet * pnn, unsigned int cInput, unsigned int cHidden, unsigned int cOutput,
-                           float rBetaHidden, float rBetaOutput);
 extern void NeuralNetDestroy(neuralnet * pnn);
 #if !defined(USE_SIMD_INSTRUCTIONS)
 extern int NeuralNetEvaluate(const neuralnet * pnn, float arInput[], float arOutput[], NNState * pnState);
