@@ -3,7 +3,7 @@
  * by Joern Thyssen, 1999-2002
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 2 of the GNU General Public License as
+ * it under the terms of version 3 or later of the GNU General Public License as
  * published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -15,27 +15,24 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: mec.h,v 1.1 2004/04/16 20:06:28 thyssen Exp $
+ * $Id: mec.h,v 1.4 2013/06/16 02:16:19 mdpetch Exp $
  */
 
 
-#ifndef _MEC_H_
-#define _MEC_H_
+#ifndef MEC_H
+#define MEC_H
 
 #include "matchequity.h"
 
 extern void
-mec( const float rGammonRate, 
-     const float rWinRate,
-     /* const */ float aarMetPC[ 2 ][ MAXSCORE ],
-     float aarMet[ MAXSCORE ][ MAXSCORE ] );
+ mec(const float rGammonRate, const float rWinRate,
+     /* const */ float aarMetPC[2][MAXSCORE],
+     float aarMet[MAXSCORE][MAXSCORE]);
 
 extern void
-mec_pc( const float rGammonRate, 
-        const float rFreeDrop2Away, 
-        const float rFreeDrop4Away, 
-        const float rWinRate,
-        float arMetPC[ MAXSCORE ] );
 
-#endif /* _MEC_H_ */
 
+mec_pc(const float rGammonRate,
+       const float rFreeDrop2Away, const float rFreeDrop4Away, const float rWinRate, float arMetPC[MAXSCORE]);
+
+#endif                          /* MEC_H */
