@@ -19,12 +19,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * 
- * $Id: multithread.c,v 1.92 2017/06/28 20:11:50 plm Exp $
+ * $Id: multithread.c,v 1.99 2018/01/24 21:32:55 plm Exp $
  */
 
 #include "config.h"
 
-#ifdef WIN32
+#if defined(WIN32)
 #include <process.h>
 #endif
 #include <stdlib.h>
@@ -41,6 +41,9 @@
 #include "lib/simd.h"
 
 #if defined(USE_MULTITHREAD)
+
+static GThread* thread[MAX_NUMTHREADS];
+
 extern unsigned int
 MT_GetNumThreads(void)
 {
@@ -50,10 +53,14 @@ MT_GetNumThreads(void)
 extern void
 MT_CloseThreads(void)
 {
-    td.closingThreads = TRUE;
+    unsigned int i;
+
+    MT_SafeSet(&td.closingThreads, TRUE);
     mt_add_tasks(td.numThreads, CloseThread, NULL, NULL);
     if (MT_WaitForTasks(NULL, 0, FALSE) != (int) td.numThreads)
         g_print("Error closing threads!\n");
+    for (i = 0; i < td.numThreads; i++)
+        g_thread_join(thread[i]);
 }
 
 static void
@@ -72,7 +79,9 @@ MT_GetTask(void)
 {
     Task *task = NULL;
 
-    Mutex_Lock(&td.queueLock, "get task");
+    multi_debug("get task asks lock (queueLock)");
+    Mutex_Lock(&td.queueLock);
+    multi_debug("get task gets lock (queueLock)");
 
     if (g_list_length(td.tasks) > 0) {
         task = (Task *) g_list_first(td.tasks)->data;
@@ -82,8 +91,8 @@ MT_GetTask(void)
         }
     }
 
-    multi_debug("get task: release");
     Mutex_Release(&td.queueLock);
+    multi_debug("get task unlocks (queueLock)");
 
     return task;
 }
@@ -99,13 +108,8 @@ MT_AbortTasks(void)
     td.result = -1;
 }
 
-#ifdef GLIB_THREADS
 static SIMD_STACKALIGN gpointer
 MT_WorkerThreadFunction(void *tld)
-#else
-static SIMD_STACKALIGN void
-MT_WorkerThreadFunction(void *tld)
-#endif
 {
 #if 0
     /* why do we need this align ? - because of a gcc bug */
@@ -136,9 +140,8 @@ MT_WorkerThreadFunction(void *tld)
                 task->fun(task->data);
                 MT_TaskDone(task);
             }
-        } while (!td.closingThreads);
+        } while (MT_SafeCompare(&td.closingThreads, FALSE));
 
-#ifdef GLIB_THREADS
 #if 0
 #if __GNUC__ && defined(WIN32)
         /* De-align stack pointer to avoid crash on exit */
@@ -146,7 +149,6 @@ MT_WorkerThreadFunction(void *tld)
 #endif
 #endif
         return NULL;
-#endif
     }
 }
 
@@ -161,22 +163,25 @@ static void
 MT_CreateThreads(void)
 {
     unsigned int i;
-    multi_debug("CreateThreads()");
+#if defined(DEBUG_MULTITHREADED)
+    gchar *buf = g_strdup_printf("create %u threads", td.numThreads);
+    multi_debug(buf);
+    g_free(buf);
+#endif
     td.result = 0;
-    td.closingThreads = FALSE;
+    MT_SafeSet(&td.closingThreads, FALSE);
     for (i = 0; i < td.numThreads; i++) {
         ThreadLocalData *pTLD = MT_CreateThreadLocalData(i);
 
-#ifdef GLIB_THREADS
 #if GLIB_CHECK_VERSION (2,32,0)
-        if (!g_thread_try_new("Worker", MT_WorkerThreadFunction, pTLD, NULL))
+        if (!(thread[i] = g_thread_try_new(NULL, MT_WorkerThreadFunction, pTLD, NULL)))
 #else
-        if (!g_thread_create(MT_WorkerThreadFunction, pTLD, FALSE, NULL))
-#endif
-#else
-        if (_beginthread(MT_WorkerThreadFunction, 0, pTLD) == 0)
+        if (!(thread[i] = g_thread_create(MT_WorkerThreadFunction, pTLD, TRUE, NULL)))
 #endif
             printf("Failed to create thread\n");
+        else {
+            multi_debug("1 thread created");
+        }
     }
     td.addedTasks = td.numThreads;
     /* Wait for all the threads to be created (timeout after 1 second) */
@@ -230,7 +235,9 @@ void
 MT_AddTask(Task * pt, gboolean lock)
 {
     if (lock) {
-        Mutex_Lock(&td.queueLock, "add task");
+        multi_debug("add task asks lock (queueLock)");
+        Mutex_Lock(&td.queueLock);
+        multi_debug("add task gets lock (queueLock)");
     }
     if (td.addedTasks == 0)
         td.result = 0;          /* Reset result for new tasks */
@@ -240,8 +247,8 @@ MT_AddTask(Task * pt, gboolean lock)
         SetManualEvent(td.activity);
     }
     if (lock) {
-        multi_debug("add task: release");
         Mutex_Release(&td.queueLock);
+        multi_debug("add task unlocks");
     }
 }
 
@@ -250,12 +257,12 @@ mt_add_tasks(unsigned int num_tasks, AsyncFun pFun, void *taskData, gpointer lin
 {
     unsigned int i;
     {
-#ifdef DEBUG_MULTITHREADED
-        char buf[20];
-        sprintf(buf, "add %u tasks", num_tasks);
-        Mutex_Lock(&td.queueLock, buf);
+#if defined(DEBUG_MULTITHREADED)
+        multi_debug("add %u tasks asks lock (queueLock)", num_tasks);
+        Mutex_Lock(&td.queueLock);
+        multi_debug("add tasks gets lock (queueLock)");
 #else
-        Mutex_Lock(&td.queueLock, NULL);
+        Mutex_Lock(&td.queueLock);
 #endif
     }
     for (i = 0; i < num_tasks; i++) {
@@ -265,15 +272,15 @@ mt_add_tasks(unsigned int num_tasks, AsyncFun pFun, void *taskData, gpointer lin
         pt->pLinkedTask = linked;
         MT_AddTask(pt, FALSE);
     }
-    multi_debug("add many release: lock");
     Mutex_Release(&td.queueLock);
+    multi_debug("add tasks unlocks (queueLock)");
 }
 
 static gboolean
 WaitForAllTasks(int time)
 {
     int j = 0;
-    while (td.doneTasks != td.totalTasks) {
+    while (!MT_SafeCompare(&td.doneTasks, td.totalTasks)) {
         if (j == 10)
             return FALSE;       /* Not done yet */
 
@@ -314,7 +321,8 @@ MT_WaitForTasks(gboolean(*pCallback) (gpointer), int callbackTime, int autosave)
     }
     multi_debug("Done waiting for all tasks");
 
-    td.doneTasks = td.addedTasks = 0;
+    MT_SafeSet(&td.doneTasks, 0);
+    td.addedTasks = 0;
     td.totalTasks = -1;
 
 #if defined(USE_GTK)
@@ -332,7 +340,7 @@ MT_SetResultFailed(void)
 extern int
 MT_GetDoneTasks(void)
 {
-    return td.doneTasks;
+    return MT_SafeGet(&td.doneTasks);
 }
 
 /* Code below used in calibrate to try and get a resonable figure for multiple threads */
@@ -414,17 +422,17 @@ mt_add_tasks(unsigned int num_tasks, AsyncFun pFun, void *taskData, gpointer lin
 extern int
 MT_GetDoneTasks(void)
 {
-    return td.doneTasks;
+    return MT_SafeGet(&td.doneTasks);
 }
 
 int
 MT_WaitForTasks(gboolean(*pCallback) (gpointer), int callbackTime, int autosave)
 {
     GList *member;
-    guint as_source, cb_source = 0;
+    guint as_source = 0, cb_source = 0;
 
     (void) callbackTime;        /* silence compiler warning */
-    td.doneTasks = 0;
+    MT_SafeSet(&td.doneTasks, 0);
 
 #if defined(USE_GTK)
     GTKSuspendInput();
@@ -436,7 +444,7 @@ MT_WaitForTasks(gboolean(*pCallback) (gpointer), int callbackTime, int autosave)
     cb_source = g_timeout_add(1000, pCallback, NULL);
     if (autosave)
         as_source = g_timeout_add(nAutoSaveTime * 60000, save_autosave, NULL);
-    for (member = g_list_first(td.tasks); member; member = member->next, td.doneTasks++) {
+    for (member = g_list_first(td.tasks); member; member = member->next, MT_SafeInc(&td.doneTasks)) {
         Task *task = member->data;
         task->fun(task->data);
         free(task->pLinkedTask);
