@@ -12,7 +12,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: multithread.h,v 1.55 2015/08/31 05:36:26 mdpetch Exp $
+ * $Id: multithread.h,v 1.60 2018/01/21 16:14:38 plm Exp $
  */
 
 #ifndef MULTITHREAD_H
@@ -26,15 +26,16 @@
 #include <windows.h>
 #endif
 
+#define UI_UPDATETIME 250
+
 #if defined(USE_MULTITHREAD)
 #include <glib.h>
 #endif
 
 #include "backgammon.h"
 
-#define UI_UPDATETIME 250
+/* #define DEBUG_MULTITHREADED 1 */
 
-/*#define DEBUG_MULTITHREADED 1 */
 #if defined (USE_MULTITHREAD) && defined(DEBUG_MULTITHREADED)
 void multi_debug(const char *str, ...);
 #else
@@ -61,7 +62,6 @@ typedef struct _ThreadLocalData {
     NNState *pnnState;
 } ThreadLocalData;
 
-#if defined(GLIB_THREADS)
 typedef struct _ManualEvent {
 #if GLIB_CHECK_VERSION (2,32,0)
     GCond cond;
@@ -70,6 +70,7 @@ typedef struct _ManualEvent {
 #endif
     int signalled;
 } *ManualEvent;
+
 typedef GPrivate *TLSItem;
 
 #if GLIB_CHECK_VERSION (2,32,0)
@@ -77,33 +78,14 @@ typedef GMutex Mutex;
 #else
 typedef GMutex *Mutex;
 #endif
-#elif defined(WIN32)            /* GLIB_THREAD */
-typedef HANDLE ManualEvent;
-typedef DWORD TLSItem;
-typedef HANDLE Event;
-typedef HANDLE Mutex;
-#define WaitForManualEvent(ME) WaitForSingleObject(ME, INFINITE)
-#define ResetManualEvent(ME) ResetEvent(ME)
-#define SetManualEvent(ME) SetEvent(ME)
-extern void TLSSetValue(TLSItem pItem, int value);
-
-#if defined (DEBUG_MULTITHREADED)
-extern void Mutex_Lock(Mutex mutex, const char *reason);
-#else
-#define Mutex_Lock(mutex, reason) WaitForSingleObject(mutex, INFINITE)
-#define Mutex_Release(mutex) ReleaseMutex(mutex)
-#endif
-
-#endif
-
-#if defined(USE_MULTITHREAD)
 
 typedef struct _ThreadData {
-    int doneTasks;
     GList *tasks;
+    int doneTasks;
     int result;
     ThreadLocalData *tld;
 
+#if defined(USE_MULTITHREAD)
     ManualEvent activity;
     TLSItem tlsItem;
     Mutex queueLock;
@@ -116,15 +98,8 @@ typedef struct _ThreadData {
 
     int closingThreads;
     unsigned int numThreads;
-} ThreadData;
-#else
-typedef struct _ThreadData {
-    int doneTasks;
-    GList *tasks;
-    int result;
-    ThreadLocalData *tld;
-} ThreadData;
 #endif
+} ThreadData;
 
 extern int MT_GetDoneTasks(void);
 extern void MT_AbortTasks(void);
@@ -141,34 +116,24 @@ extern ThreadData td;
 
 #if defined(USE_MULTITHREAD)
 
-#if defined(GLIB_THREADS)
 extern void ResetManualEvent(ManualEvent ME);
-extern void Mutex_Lock(Mutex *mutex, const char *reason);
+extern void Mutex_Lock(Mutex *mutex);
 extern void Mutex_Release(Mutex *mutex);
 extern void WaitForManualEvent(ManualEvent ME);
 extern void SetManualEvent(ManualEvent ME);
 extern void TLSSetValue(TLSItem pItem, size_t value);
-#endif
 extern void TLSFree(TLSItem pItem);
 extern void InitManualEvent(ManualEvent * pME);
 extern void FreeManualEvent(ManualEvent ME);
 extern void InitMutex(Mutex * pMutex);
 extern void FreeMutex(Mutex * mutex);
 
-#define UI_UPDATETIME 250
-
-#if defined (GLIB_THREADS)
 #define TLSGet(item) *((size_t*)g_private_get(item))
 
-#else                           /* WIN32 */
-#define TLSGet(item) *((int*)TlsGetValue(item))
-#endif                          /* GLIB_THREADS */
-
 #if !defined(MAX_NUMTHREADS)
 #define MAX_NUMTHREADS 48
 #endif
 
-
 extern void MT_Release(void);
 extern void MT_Exclusive(void);
 extern void MT_StartThreads(void);
@@ -185,7 +150,6 @@ extern unsigned int MT_GetNumThreads(void);
 #define MT_Get_nnState() ((ThreadLocalData *)TLSGet(td.tlsItem))->pnnState
 #define MT_Get_aMoves() ((ThreadLocalData *)TLSGet(td.tlsItem))->aMoves
 
-#if defined (GLIB_THREADS)
 #if GLIB_CHECK_VERSION (2,30,0)
 #define MT_SafeIncValue(x) (g_atomic_int_add(x, 1) + 1)
 #define MT_SafeIncCheck(x) (g_atomic_int_add(x, 1))
@@ -201,14 +165,9 @@ extern unsigned int MT_GetNumThreads(void);
 #define MT_SafeAdd(x, y) g_atomic_int_add(x, y)
 #define MT_SafeDec(x) g_atomic_int_add(x, -1)
 #define MT_SafeDecCheck(x) g_atomic_int_dec_and_test(x)
-#else
-#define MT_SafeInc(x) (void)InterlockedIncrement((long*)x)
-#define MT_SafeIncValue(x) InterlockedIncrement((long*)x)
-#define MT_SafeIncCheck(x) (InterlockedIncrement((long*)x) > 1)
-#define MT_SafeAdd(x, y) InterlockedExchangeAdd((long*)x, y)
-#define MT_SafeDec(x) (void)InterlockedDecrement((long*)x)
-#define MT_SafeDecCheck(x) (InterlockedDecrement((long*)x) == 0)
-#endif
+#define MT_SafeGet(x) g_atomic_int_get(x)
+#define MT_SafeSet(x, y) g_atomic_int_set(x, y)
+#define MT_SafeCompare(x, y) g_atomic_int_compare_and_exchange(x, y, y)
 
 #else                           /*USE_MULTITHREAD */
 #if !defined(MAX_NUMTHREADS)
@@ -225,6 +184,9 @@ extern int asyncRet;
 #define MT_SafeAdd(x, y) ((*x) += y)
 #define MT_SafeDec(x) (--(*x))
 #define MT_SafeDecCheck(x) ((--(*x)) == 0)
+#define MT_SafeGet(x) (*x)
+#define MT_SafeSet(x, y) ((*x) = y)
+#define MT_SafeCompare(x, y) ((*x) == y)
 #define MT_GetThreadID() 0
 #define MT_Get_nnState() td.tld->pnnState
 #define MT_Get_aMoves() td.tld->aMoves
