@@ -9,10 +9,10 @@
 #
 # by Joern Thyssen <jth@gnubg.org>, 2003
 #
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of version 3 or later of the GNU General Public License as
-# published by the Free Software Foundation.
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,19 +20,25 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-# $Id: gnubg.py,v 1.11 2013/06/24 22:01:55 mdpetch Exp $
+# $Id: gnubg.py,v 1.18 2017/11/13 21:07:43 plm Exp $
 #
 
-# Add the scrpts directory to the module path to allow
-# for modules from this directory to be improted
+# Add the scripts directory to the module path to allow
+# for modules from this directory to be imported
 import sys
+import os
+
 sys.path.insert(1, './scripts')
-#import site
+if sys.platform == 'win32':
+    os.environ['TCL_LIBRARY']='PythonLib/lib/tcl8'
+
+if sys.version_info >= (3, 0):
+    import builtins as bi
+else:
+    import __builtin__ as bi
 
-import __builtin__
 
 def setinterpreterquit():
     class interpreterquit(object):
@@ -42,10 +48,10 @@ def setinterpreterquit():
             if not ('idlelib' in sys.stdin.__class__.__module__):
                 raise SystemExit(0)
             else:
-                print 'Press Ctrl-D to exit'
+                print('Press Ctrl-D to exit')
 
-    __builtin__.quit = interpreterquit()
-    __builtin__.exit = interpreterquit()
+    bi.quit = interpreterquit()
+    bi.exit = interpreterquit()
 
 setinterpreterquit()
 
@@ -91,9 +97,18 @@ def gnubg_InteractivePyShell_tui(argv=[''], banner=None):
         sys.argv = argv
 
         # Check for IPython as it is generally the best cmdline interpreter
-        from IPython.frontend.terminal.embed import InteractiveShellEmbed
+        from IPython import version_info as ipy_version_info
+        if ipy_version_info[0] >= 1:
+            from IPython.terminal.embed import InteractiveShellEmbed
+        else:
+            from IPython.frontend.terminal.embed import InteractiveShellEmbed
+
         from IPython import __version__ as ipyversion
-        from IPython.config.loader import Config
+        if ipy_version_info[0] >= 4:
+            from traitlets.config.loader import Config
+        else:
+            from IPython.config.loader import Config
+
     except:
         # Otherwise use standard interpreter
         if (banner == None):
@@ -128,10 +143,10 @@ def gnubg_InteractivePyShell_tui(argv=[''], banner=None):
             # If we get this far we are on Win32 and too early
             # a version to support the embedded interpreter so
             # we simulate one
-            print banner
-            print '<Control-Z> and <Return> to exit'
+            print(banner)
+            print('<Control-Z> and <Return> to exit')
             while True:
-                print '>>> ',
+                print('>>> ',)
                 line = sys.stdin.readline()
                 if not line:
                     break
@@ -146,12 +161,18 @@ def gnubg_InteractivePyShell_tui(argv=[''], banner=None):
 
     try:
         # Launch IPython interpreter
-        cfg = Config()
-        prompt_config = cfg.PromptManager
-        prompt_config.in_template = 'In <\\#> > '
-        prompt_config.in2_template = '   .\\D. > '
-        prompt_config.out_template = 'Out<\\#> > '
-        cfg.InteractiveShell.confirm_exit = False
+        if ipy_version_info[0] <= 4:
+            cfg = Config()
+            prompt_config = cfg.PromptManager
+            prompt_config.in_template = 'In <\\#> > '
+            prompt_config.in2_template = '   .\\D. > '
+            prompt_config.out_template = 'Out<\\#> > '
+            cfg.InteractiveShell.confirm_exit = False
+        else:
+            # FIXME:
+            # As of IPython 5.0 `PromptManager` config will have no effect and
+            # has been replaced by TerminalInteractiveShell.prompts_class
+            cfg = None
 
         if banner == None:
             banner = 'IPython ' + ipyversion + ', Python ' + sys.version
