@@ -157,8 +157,8 @@ static char *Concatenate( listOLD *pl ) {
 
 /* In a future release of Bison, this section will be replaced
    by #include "y.tab.h".  */
-#ifndef YY_SGF_SGF_Y_H_INCLUDED
-# define YY_SGF_SGF_Y_H_INCLUDED
+#ifndef YY_SGF_Y_TAB_H_INCLUDED
+# define YY_SGF_Y_TAB_H_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -205,7 +205,7 @@ extern YYSTYPE sgflval;
 
 int sgfparse (void);
 
-#endif /* !YY_SGF_SGF_Y_H_INCLUDED  */
+#endif /* !YY_SGF_Y_TAB_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
